@@ -429,13 +429,25 @@ delete_share (GtkTreeIter *iter, OobsShare *share, OobsListIter *list_iter)
 
 void
 share_settings_dialog_run (const gchar *path, gboolean standalone)
+{
+	GtkTreeIter   iter;
+
+	/* check whether the path already exists */
+	if (table_get_iter_with_path (path, &iter))
+		share_settings_dialog_run_for_iter (path, &iter, standalone);
+	else
+		share_settings_dialog_run_for_iter (path, NULL, standalone);
+}
+
+void
+share_settings_dialog_run_for_iter (const gchar *path,
+				    GtkTreeIter *iter,
+				    gboolean standalone)
 {
 	GtkWidget    *dialog;
 	gint          response;
 	OobsShare    *new_share, *share;
 	OobsListIter *list_iter;
-	GtkTreeIter   iter;
-	gboolean      path_exists;
 	gchar        *title;
 	GtkWidget    *name_entry, *file_chooser;
 
@@ -443,11 +455,8 @@ share_settings_dialog_run (const gchar *path, gboolean standalone)
 	list_iter = NULL;
 	dialog = share_settings_prepare_dialog (path, standalone);
 
-	/* check whether the path already exists */
-	path_exists = table_get_iter_with_path (path, &iter);
-
-	if (path_exists) {
-		share = table_get_share_at_iter (&iter, &list_iter);
+	if (iter) {
+		share = table_get_share_at_iter (iter, &list_iter);
 		share_settings_set_share (share);
 
 		title = g_strdup_printf ("Settings for folder '%s'",
@@ -460,7 +469,7 @@ share_settings_dialog_run (const gchar *path, gboolean standalone)
 		gtk_window_set_title (GTK_WINDOW (dialog), "Share Folder");
 
 		if (!path) {
-			/* make sure the path gets filled */
+			/* make sure the path entry gets filled in */
 			file_chooser = gst_dialog_get_widget (tool->main_dialog, "share_path");
 			path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_chooser));
 		}
@@ -468,23 +477,27 @@ share_settings_dialog_run (const gchar *path, gboolean standalone)
 		share_settings_set_name_from_folder (path);
 	}
 
+	gst_dialog_add_edit_dialog (tool->main_dialog, dialog);
+
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (tool->main_dialog));
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_hide (dialog);
 
+	gst_dialog_remove_edit_dialog (tool->main_dialog, dialog);
+
 	if (response == GTK_RESPONSE_OK) {
 		new_share = share_settings_get_share ();
 
 		if (new_share) {
 			/* FIXME: check type, and move
 			 * share between lists if necessary */
-			if (path_exists)
-				modify_share (new_share, share, list_iter, &iter);
+			if (iter)
+				modify_share (new_share, share, list_iter, iter);
 			else
 				add_new_share (new_share);
 		} else {
-			if (path_exists)
-				delete_share (&iter, share, list_iter);
+			if (iter)
+				delete_share (iter, share, list_iter);
 		}
 	}
 
@@ -495,4 +508,7 @@ share_settings_dialog_run (const gchar *path, gboolean standalone)
 
 	if (list_iter)
 		oobs_list_iter_free (list_iter);
+
+	if (standalone)
+		gtk_main_quit ();
 }
